
CREATE 
VIEW DWH_X_INV_PLAN_PER_FACTS_MV
WITH SCHEMABINDING
AS
/* Summarize Plans to Investment */
SELECT FP.INVESTMENT_KEY,
       F.PERIOD_KEY,
       COUNT_BIG(*) RECORD_COUNT, 
       SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'BUDGET' THEN F.PLAN_COST ELSE 0 END) BDGT_COST,
       SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'BUDGET' AND ISNULL(FP.COST_TYPE_KEY,'OPERATING') = 'CAPITAL' THEN F.PLAN_COST ELSE 0 END) BDGT_CAP_COST,
       CASE WHEN SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'BUDGET' THEN F.PLAN_COST ELSE 0 END) <> 0 THEN
           (SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'BUDGET' AND ISNULL(FP.COST_TYPE_KEY,'OPERATING') = 'CAPITAL' THEN F.PLAN_COST ELSE 0 END) /
            SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'BUDGET' THEN F.PLAN_COST ELSE 0 END)) * 100 ELSE 0 END BDGT_CAP_PCT,
       SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'BUDGET' AND ISNULL(FP.COST_TYPE_KEY,'OPERATING') = 'OPERATING' THEN F.PLAN_COST ELSE 0 END) BDGT_OPER_COST,
       CASE WHEN SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'BUDGET' THEN F.PLAN_COST ELSE 0 END) <> 0 THEN
           (SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'BUDGET' AND ISNULL(FP.COST_TYPE_KEY,'OPERATING') = 'OPERATING' THEN F.PLAN_COST ELSE 0 END) /
            SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'BUDGET' THEN F.PLAN_COST ELSE 0 END)) * 100 ELSE 0 END BDGT_OPER_PCT,
       SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'BUDGET' THEN F.PLAN_COST - F.ACTUAL_COST ELSE 0 END) BDGT_ACTUAL_COST_VAR,
       SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'BUDGET' AND ISNULL(FP.COST_TYPE_KEY,'OPERATING') = 'CAPITAL' THEN F.PLAN_COST - F.ACTUAL_COST ELSE 0 END) BDGT_ACTUAL_CAP_COST_VAR,
       SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'BUDGET' AND ISNULL(FP.COST_TYPE_KEY,'OPERATING') = 'OPERATING' THEN F.PLAN_COST - F.ACTUAL_COST ELSE 0 END) BDGT_ACTUAL_OPER_COST_VAR,
       SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' THEN F.PLAN_COST ELSE 0 END) PLAN_COST,
       SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' AND ISNULL(FP.COST_TYPE_KEY,'OPERATING') = 'CAPITAL' THEN F.PLAN_COST ELSE 0 END) PLAN_CAP_COST,
       CASE WHEN SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' THEN F.PLAN_COST ELSE 0 END) <> 0 THEN
           (SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' AND ISNULL(FP.COST_TYPE_KEY,'OPERATING') = 'CAPITAL' THEN F.PLAN_COST ELSE 0 END) /
            SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' THEN F.PLAN_COST ELSE 0 END)) * 100 ELSE 0 END PLAN_CAP_PCT,
       SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' AND ISNULL(FP.COST_TYPE_KEY,'OPERATING') = 'OPERATING' THEN F.PLAN_COST ELSE 0 END) PLAN_OPER_COST,
       CASE WHEN SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' THEN F.PLAN_COST ELSE 0 END) <> 0 THEN
           (SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' AND ISNULL(FP.COST_TYPE_KEY,'OPERATING') = 'OPERATING' THEN F.PLAN_COST ELSE 0 END) /
            SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' THEN F.PLAN_COST ELSE 0 END)) * 100 ELSE 0 END PLAN_OPER_PCT,
       SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' THEN F.PLAN_COST - F.ACTUAL_COST ELSE 0 END) PLAN_ACTUAL_COST_VAR,
       SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' AND ISNULL(FP.COST_TYPE_KEY,'OPERATING') = 'CAPITAL' THEN F.PLAN_COST - F.ACTUAL_COST ELSE 0 END) PLAN_ACTUAL_CAP_COST_VAR,
       SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' AND ISNULL(FP.COST_TYPE_KEY,'OPERATING') = 'OPERATING' THEN F.PLAN_COST - F.ACTUAL_COST ELSE 0 END) PLAN_ACTUAL_OPER_COST_VAR,
       SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' THEN F.FCST_COST ELSE 0 END) FCST_COST,
       SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' AND ISNULL(FP.COST_TYPE_KEY,'OPERATING') = 'CAPITAL' THEN F.FCST_COST ELSE 0 END) FCST_CAP_COST,
       CASE WHEN SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' THEN F.FCST_COST ELSE 0 END) <> 0 THEN
           (SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' AND ISNULL(FP.COST_TYPE_KEY,'OPERATING') = 'CAPITAL' THEN F.FCST_COST ELSE 0 END) /
            SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' THEN F.FCST_COST ELSE 0 END)) * 100 ELSE 0 END FCST_CAP_PCT,
       SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' AND ISNULL(FP.COST_TYPE_KEY,'OPERATING') = 'OPERATING' THEN F.FCST_COST ELSE 0 END) FCST_OPER_COST,
       CASE WHEN SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' THEN F.FCST_COST ELSE 0 END) <> 0 THEN
           (SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' AND ISNULL(FP.COST_TYPE_KEY,'OPERATING') = 'OPERATING' THEN F.FCST_COST ELSE 0 END) /
            SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' THEN F.FCST_COST ELSE 0 END)) * 100 ELSE 0 END FCST_OPER_PCT,
       SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' THEN F.FCST_COST - F.ACTUAL_COST ELSE 0 END) FCST_COST_REMAIN,
       SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' AND ISNULL(FP.COST_TYPE_KEY,'OPERATING') = 'CAPITAL' THEN F.FCST_COST - F.ACTUAL_COST ELSE 0 END) FCST_CAP_COST_REMAIN,
       SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' AND ISNULL(FP.COST_TYPE_KEY,'OPERATING') = 'OPERATING' THEN F.FCST_COST - F.ACTUAL_COST ELSE 0 END) FCST_OPER_COST_REMAIN,
       SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'BUDGET' THEN F.PLAN_COST ELSE 0 END -
           CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' THEN F.FCST_COST ELSE 0 END) BDGT_FCST_COST_VAR, 
       SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'BUDGET' AND ISNULL(FP.COST_TYPE_KEY,'OPERATING') = 'CAPITAL' THEN F.PLAN_COST ELSE 0 END -
           CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' AND ISNULL(FP.COST_TYPE_KEY,'OPERATING') = 'CAPITAL' THEN F.FCST_COST ELSE 0 END) BDGT_FCST_CAP_COST_VAR, 
       SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'BUDGET' AND ISNULL(FP.COST_TYPE_KEY,'OPERATING') = 'OPERATING' THEN F.PLAN_COST ELSE 0 END -
           CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' AND ISNULL(FP.COST_TYPE_KEY,'OPERATING') = 'OPERATING' THEN F.FCST_COST ELSE 0 END) BDGT_FCST_OPER_COST_VAR, 
       SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' THEN F.PLAN_COST ELSE 0 END -
           CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' THEN F.FCST_COST ELSE 0 END) PLAN_FCST_COST_VAR, 
       SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' AND ISNULL(FP.COST_TYPE_KEY,'OPERATING') = 'CAPITAL' THEN F.PLAN_COST ELSE 0 END -
           CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' AND ISNULL(FP.COST_TYPE_KEY,'OPERATING') = 'CAPITAL' THEN F.FCST_COST ELSE 0 END) PLAN_FCST_CAP_COST_VAR, 
       SUM(CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' AND ISNULL(FP.COST_TYPE_KEY,'OPERATING') = 'OPERATING' THEN F.PLAN_COST ELSE 0 END -
           CASE WHEN FP.FIN_PLAN_TYPE_KEY = 'FORECAST' AND ISNULL(FP.COST_TYPE_KEY,'OPERATING') = 'OPERATING' THEN F.FCST_COST ELSE 0 END) PLAN_FCST_OPER_COST_VAR,
       SUM(CASE WHEN FP.DW_UPDATED_DATE > A.DW_LOAD_END_DATE OR F.DW_UPDATED_DATE > A.DW_LOAD_END_DATE THEN 1 ELSE 0 END) UNPROCESSED_RECORD_COUNT
FROM   ppm_dwh.DWH_FIN_PLAN FP
       INNER JOIN ppm_dwh.DWH_FIN_PLAN_PERIOD_FACTS F ON FP.PLAN_DETAIL_KEY = F.PLAN_DETAIL_KEY
       INNER JOIN ppm_dwh.DWH_CFG_AUDIT A ON 1=1
WHERE  FP.IS_PLAN_OF_RECORD = 1 AND UPPER(A.table_name) =UPPER('DWH_INV_PERIOD_FACTS')
AND    FP.FIN_PLAN_TYPE_KEY IN ('BUDGET','FORECAST')
GROUP BY FP.INVESTMENT_KEY, F.PERIOD_KEY
UNION ALL 
SELECT I.INVESTMENT_KEY,
       P.PERIOD_KEY,
       1 RECORD_COUNT,
       CASE WHEN P.BDGT_COST_PERIOD_DAYS <> 0 AND P.BDGT_COST_TOTAL_DAYS <> 0
            THEN (I.BDGT_COST / P.BDGT_COST_TOTAL_DAYS) * P.BDGT_COST_PERIOD_DAYS
            ELSE 0 END BDGT_COST,
       CASE WHEN P.BDGT_COST_PERIOD_DAYS <> 0 AND P.BDGT_COST_TOTAL_DAYS <> 0
            THEN (I.BDGT_CAP_COST / P.BDGT_COST_TOTAL_DAYS) * P.BDGT_COST_PERIOD_DAYS
            ELSE 0 END BDGT_CAP_COST,
       CASE WHEN P.BDGT_COST_PERIOD_DAYS <> 0 AND P.BDGT_COST_TOTAL_DAYS <> 0 AND I.BDGT_COST <> 0
            THEN (I.BDGT_CAP_COST / I.BDGT_COST) * 100
            ELSE 0 END BDGT_CAP_PCT,
       CASE WHEN P.BDGT_COST_PERIOD_DAYS <> 0 AND P.BDGT_COST_TOTAL_DAYS <> 0
            THEN (I.BDGT_OPER_COST / P.BDGT_COST_TOTAL_DAYS) * P.BDGT_COST_PERIOD_DAYS
            ELSE 0 END BDGT_OPER_COST,
       CASE WHEN P.BDGT_COST_PERIOD_DAYS <> 0 AND P.BDGT_COST_TOTAL_DAYS <> 0 AND I.BDGT_COST <> 0
            THEN (I.BDGT_OPER_COST / I.BDGT_COST) * 100
            ELSE 0 END BDGT_OPER_PCT,
       CASE WHEN P.BDGT_COST_PERIOD_DAYS <> 0 AND P.BDGT_COST_TOTAL_DAYS <> 0
            THEN ((I.BDGT_COST / P.BDGT_COST_TOTAL_DAYS) * P.BDGT_COST_PERIOD_DAYS) - ISNULL(TF.ACTUAL_COST,0)
            ELSE 0 END BDGT_ACTUAL_COST_VAR,
       CASE WHEN P.BDGT_COST_PERIOD_DAYS <> 0 AND P.BDGT_COST_TOTAL_DAYS <> 0
            THEN ((I.BDGT_CAP_COST / P.BDGT_COST_TOTAL_DAYS) * P.BDGT_COST_PERIOD_DAYS) - ISNULL(TF.ACTUAL_CAP_COST,0)
            ELSE 0 END BDGT_ACTUAL_CAP_COST_VAR,
       CASE WHEN P.BDGT_COST_PERIOD_DAYS <> 0 AND P.BDGT_COST_TOTAL_DAYS <> 0
            THEN ((I.BDGT_OPER_COST / P.BDGT_COST_TOTAL_DAYS) * P.BDGT_COST_PERIOD_DAYS) - ISNULL(TF.ACTUAL_OPER_COST,0)
            ELSE 0 END BDGT_ACTUAL_OPER_COST_VAR,
       CASE WHEN P.PLAN_COST_PERIOD_DAYS <> 0 AND P.PLAN_COST_TOTAL_DAYS <> 0
            THEN (I.PLAN_COST / P.PLAN_COST_TOTAL_DAYS) * P.PLAN_COST_PERIOD_DAYS
            ELSE 0 END PLAN_COST,
       CASE WHEN P.PLAN_COST_PERIOD_DAYS <> 0 AND P.PLAN_COST_TOTAL_DAYS <> 0
            THEN (I.PLAN_CAP_COST / P.PLAN_COST_TOTAL_DAYS) * P.PLAN_COST_PERIOD_DAYS
            ELSE 0 END PLAN_CAP_COST,
       CASE WHEN P.PLAN_COST_PERIOD_DAYS <> 0 AND P.PLAN_COST_TOTAL_DAYS <> 0 AND I.PLAN_COST <> 0
            THEN (I.PLAN_CAP_COST / I.PLAN_COST) * 100
            ELSE 0 END PLAN_CAP_PCT,
       CASE WHEN P.PLAN_COST_PERIOD_DAYS <> 0 AND P.PLAN_COST_TOTAL_DAYS <> 0
            THEN (I.PLAN_OPER_COST / P.PLAN_COST_TOTAL_DAYS) * P.PLAN_COST_PERIOD_DAYS
            ELSE 0 END PLAN_OPER_COST,
       CASE WHEN P.PLAN_COST_PERIOD_DAYS <> 0 AND P.PLAN_COST_TOTAL_DAYS <> 0 AND I.PLAN_COST <> 0
            THEN (I.PLAN_OPER_COST / I.PLAN_COST) * 100
            ELSE 0 END PLAN_OPER_PCT,
       CASE WHEN P.PLAN_COST_PERIOD_DAYS <> 0 AND P.PLAN_COST_TOTAL_DAYS <> 0
            THEN ((I.PLAN_COST / P.PLAN_COST_TOTAL_DAYS) * P.PLAN_COST_PERIOD_DAYS) - ISNULL(TF.ACTUAL_COST,0)
            ELSE 0 END PLAN_ACTUAL_COST_VAR,
       CASE WHEN P.PLAN_COST_PERIOD_DAYS <> 0 AND P.PLAN_COST_TOTAL_DAYS <> 0
            THEN ((I.PLAN_CAP_COST / P.PLAN_COST_TOTAL_DAYS) * P.PLAN_COST_PERIOD_DAYS) - ISNULL(TF.ACTUAL_CAP_COST,0)
            ELSE 0 END PLAN_ACTUAL_CAP_COST_VAR,
       CASE WHEN P.PLAN_COST_PERIOD_DAYS <> 0 AND P.PLAN_COST_TOTAL_DAYS <> 0
            THEN ((I.PLAN_OPER_COST / P.PLAN_COST_TOTAL_DAYS) * P.PLAN_COST_PERIOD_DAYS) - ISNULL(TF.ACTUAL_OPER_COST,0)
            ELSE 0 END PLAN_ACTUAL_OPER_COST_VAR,
       CASE WHEN P.PLAN_COST_PERIOD_DAYS <> 0 AND P.PLAN_COST_TOTAL_DAYS <> 0
            THEN CASE WHEN P.PERIOD_FINISH >= GETDATE()
                      THEN (I.PLAN_COST / P.PLAN_COST_TOTAL_DAYS) * P.PLAN_COST_PERIOD_DAYS
                      ELSE ISNULL(TF.ACTUAL_COST,0) END
            ELSE 0 END FCST_COST, 
       CASE WHEN P.PLAN_COST_PERIOD_DAYS <> 0 AND P.PLAN_COST_TOTAL_DAYS <> 0
            THEN CASE WHEN P.PERIOD_FINISH >= GETDATE() 
                      THEN (I.PLAN_CAP_COST / P.PLAN_COST_TOTAL_DAYS) * P.PLAN_COST_PERIOD_DAYS
                      ELSE ISNULL(TF.ACTUAL_CAP_COST,0) END
            ELSE 0 END FCST_CAP_COST,
       CASE WHEN P.PLAN_COST_PERIOD_DAYS <> 0 AND P.PLAN_COST_TOTAL_DAYS <> 0 AND
               ((P.PERIOD_FINISH >= GETDATE() AND I.PLAN_COST <> 0) OR (P.PERIOD_FINISH < GETDATE() AND ISNULL(TF.ACTUAL_COST,0) <> 0)) 
            THEN (CASE WHEN P.PERIOD_FINISH >= GETDATE()
                       THEN (I.PLAN_CAP_COST / P.PLAN_COST_TOTAL_DAYS) * P.PLAN_COST_PERIOD_DAYS
                       ELSE ISNULL(TF.ACTUAL_CAP_COST,0) END  /
                  CASE WHEN P.PERIOD_FINISH >= GETDATE()
                       THEN (I.PLAN_COST / P.PLAN_COST_TOTAL_DAYS) * P.PLAN_COST_PERIOD_DAYS
                       ELSE ISNULL(TF.ACTUAL_COST,0) END) * 100
            ELSE 0 END FCST_CAP_PCT,
       CASE WHEN P.PLAN_COST_PERIOD_DAYS <> 0 AND P.PLAN_COST_TOTAL_DAYS <> 0
            THEN CASE WHEN P.PERIOD_FINISH >= GETDATE()
                      THEN (I.PLAN_OPER_COST / P.PLAN_COST_TOTAL_DAYS) * P.PLAN_COST_PERIOD_DAYS
                      ELSE ISNULL(TF.ACTUAL_OPER_COST,0) END
            ELSE 0 END FCST_OPER_COST,
       CASE WHEN P.PLAN_COST_PERIOD_DAYS <> 0 AND P.PLAN_COST_TOTAL_DAYS <> 0 AND
               ((P.PERIOD_FINISH >= GETDATE() AND I.PLAN_COST <> 0) OR (P.PERIOD_FINISH < GETDATE() AND ISNULL(TF.ACTUAL_COST,0) <> 0)) 
            THEN (CASE WHEN P.PERIOD_FINISH >= GETDATE()
                       THEN (I.PLAN_OPER_COST / P.PLAN_COST_TOTAL_DAYS) * P.PLAN_COST_PERIOD_DAYS
                       ELSE ISNULL(TF.ACTUAL_OPER_COST,0) END /
                  CASE WHEN P.PERIOD_FINISH >= GETDATE()
                       THEN (I.PLAN_COST / P.PLAN_COST_TOTAL_DAYS) * P.PLAN_COST_PERIOD_DAYS
                       ELSE ISNULL(TF.ACTUAL_COST,0) END) * 100
            ELSE 0 END FCST_OPER_PCT,
       CASE WHEN P.PLAN_COST_PERIOD_DAYS <> 0 AND P.PLAN_COST_TOTAL_DAYS <> 0
            THEN CASE WHEN P.PERIOD_FINISH >= GETDATE()
                      THEN (I.PLAN_COST / P.PLAN_COST_TOTAL_DAYS) * P.PLAN_COST_PERIOD_DAYS
                      ELSE ISNULL(TF.ACTUAL_COST,0) END - ISNULL(TF.ACTUAL_COST,0)
            ELSE 0 END FCST_COST_REMAIN,
       CASE WHEN P.PLAN_COST_PERIOD_DAYS <> 0 AND P.PLAN_COST_TOTAL_DAYS <> 0
            THEN CASE WHEN P.PERIOD_FINISH >= GETDATE()
                 THEN (I.PLAN_CAP_COST / P.PLAN_COST_TOTAL_DAYS) * P.PLAN_COST_PERIOD_DAYS
                 ELSE ISNULL(TF.ACTUAL_CAP_COST,0) END - ISNULL(TF.ACTUAL_CAP_COST,0)
            ELSE 0 END FCST_CAP_COST_REMAIN,
       CASE WHEN P.PLAN_COST_PERIOD_DAYS <> 0 AND P.PLAN_COST_TOTAL_DAYS <> 0
            THEN CASE WHEN P.PERIOD_FINISH >= GETDATE()
                      THEN (I.PLAN_OPER_COST / P.PLAN_COST_TOTAL_DAYS) * P.PLAN_COST_PERIOD_DAYS
                      ELSE ISNULL(TF.ACTUAL_OPER_COST,0) END - ISNULL(TF.ACTUAL_OPER_COST,0)
            ELSE 0 END FCST_OPER_COST_REMAIN,
       CASE WHEN P.BDGT_COST_PERIOD_DAYS <> 0 AND P.BDGT_COST_TOTAL_DAYS <> 0
            THEN (I.BDGT_COST / P.BDGT_COST_TOTAL_DAYS) * P.BDGT_COST_PERIOD_DAYS
            ELSE 0 END - CASE WHEN P.PLAN_COST_PERIOD_DAYS <> 0 AND P.PLAN_COST_TOTAL_DAYS <> 0
                              THEN CASE WHEN P.PERIOD_FINISH >= GETDATE()
                                        THEN (I.PLAN_COST / P.PLAN_COST_TOTAL_DAYS) * P.PLAN_COST_PERIOD_DAYS
                                        ELSE ISNULL(TF.ACTUAL_COST,0) END
                              ELSE 0 END BDGT_FCST_COST_VAR,
       CASE WHEN P.BDGT_COST_PERIOD_DAYS <> 0 AND P.BDGT_COST_TOTAL_DAYS <> 0
            THEN (I.BDGT_CAP_COST / P.BDGT_COST_TOTAL_DAYS) * P.BDGT_COST_PERIOD_DAYS
            ELSE 0 END - CASE WHEN P.PLAN_COST_PERIOD_DAYS <> 0 AND P.PLAN_COST_TOTAL_DAYS <> 0
                              THEN CASE WHEN P.PERIOD_FINISH >= GETDATE()
                                        THEN (I.PLAN_CAP_COST / P.PLAN_COST_TOTAL_DAYS) * P.PLAN_COST_PERIOD_DAYS
                                        ELSE ISNULL(TF.ACTUAL_CAP_COST,0) END 
                              ELSE 0 END BDGT_FCST_CAP_COST_VAR,
       CASE WHEN P.BDGT_COST_PERIOD_DAYS <> 0 AND P.BDGT_COST_TOTAL_DAYS <> 0
            THEN (I.BDGT_OPER_COST / P.BDGT_COST_TOTAL_DAYS) * P.BDGT_COST_PERIOD_DAYS
            ELSE 0 END - CASE WHEN P.PLAN_COST_PERIOD_DAYS <> 0 AND P.PLAN_COST_TOTAL_DAYS <> 0
                              THEN CASE WHEN P.PERIOD_FINISH >= GETDATE()
                                        THEN (I.PLAN_OPER_COST / P.PLAN_COST_TOTAL_DAYS) * P.PLAN_COST_PERIOD_DAYS
                                        ELSE ISNULL(TF.ACTUAL_OPER_COST,0) END
                              ELSE 0 END BDGT_FCST_OPER_COST_VAR,
       CASE WHEN P.PLAN_COST_PERIOD_DAYS <> 0 AND P.PLAN_COST_TOTAL_DAYS <> 0
            THEN (I.PLAN_COST / P.PLAN_COST_TOTAL_DAYS) * P.PLAN_COST_PERIOD_DAYS
            ELSE 0 END - CASE WHEN P.PLAN_COST_PERIOD_DAYS <> 0 AND P.PLAN_COST_TOTAL_DAYS <> 0
                              THEN CASE WHEN P.PERIOD_FINISH >= GETDATE()
                                        THEN (I.PLAN_COST / P.PLAN_COST_TOTAL_DAYS) * P.PLAN_COST_PERIOD_DAYS
                                        ELSE ISNULL(TF.ACTUAL_COST,0) END
                              ELSE 0 END PLAN_FCST_COST_VAR,
       CASE WHEN P.PLAN_COST_PERIOD_DAYS <> 0 AND P.PLAN_COST_TOTAL_DAYS <> 0
            THEN (I.PLAN_CAP_COST / P.PLAN_COST_TOTAL_DAYS) * P.PLAN_COST_PERIOD_DAYS
            ELSE 0 END - CASE WHEN P.PLAN_COST_PERIOD_DAYS <> 0 AND P.PLAN_COST_TOTAL_DAYS <> 0
                              THEN CASE WHEN P.PERIOD_FINISH >= GETDATE()
                                        THEN (I.PLAN_CAP_COST / P.PLAN_COST_TOTAL_DAYS) * P.PLAN_COST_PERIOD_DAYS
                                        ELSE ISNULL(TF.ACTUAL_CAP_COST,0) END
                              ELSE 0 END PLAN_FCST_CAP_COST_VAR,
       CASE WHEN P.PLAN_COST_PERIOD_DAYS <> 0 AND P.PLAN_COST_TOTAL_DAYS <> 0
            THEN (I.PLAN_OPER_COST / P.PLAN_COST_TOTAL_DAYS) * P.PLAN_COST_PERIOD_DAYS
            ELSE 0 END - CASE WHEN P.PLAN_COST_PERIOD_DAYS <> 0 AND P.PLAN_COST_TOTAL_DAYS <> 0
                              THEN CASE WHEN P.PERIOD_FINISH >= GETDATE()
                                        THEN (I.PLAN_OPER_COST / P.PLAN_COST_TOTAL_DAYS) * P.PLAN_COST_PERIOD_DAYS
                                        ELSE ISNULL(TF.ACTUAL_OPER_COST,0) END
                              ELSE 0 END PLAN_FCST_OPER_COST_VAR, 
       CASE WHEN I.DW_UPDATED_DATE > A.DW_LOAD_END_DATE OR ISNULL(TF.UNPROCESSED_RECORD_COUNT,0) > 0 THEN 1 ELSE 0 END UNPROCESSED_RECORD_COUNT
FROM   PPM_DWH.DWH_X_INV_SUM_FACTS I
       INNER JOIN PPM_DWH.DWH_CFG_AUDIT A ON UPPER(A.TABLE_NAME) = 'DWH_INV_PERIOD_FACTS'
       INNER JOIN (SELECT I.INVESTMENT_KEY,
                          P.PERIOD_KEY,
                          P.PERIOD_END_DATE PERIOD_FINISH,
                          CASE WHEN I.BDGT_COST_START <= P.PERIOD_END_DATE AND I.BDGT_COST_FINISH >= P.PERIOD_START_DATE
                               THEN DATEDIFF(D,CASE WHEN I.BDGT_COST_START > P.PERIOD_START_DATE THEN I.BDGT_COST_START ELSE P.PERIOD_START_DATE END,
                                               CASE WHEN I.BDGT_COST_FINISH < P.PERIOD_END_DATE THEN I.BDGT_COST_FINISH ELSE P.PERIOD_END_DATE END) + 1
                               ELSE 0 END BDGT_COST_PERIOD_DAYS,
                          DATEDIFF(D,I.BDGT_COST_START,I.BDGT_COST_FINISH) + 1 BDGT_COST_TOTAL_DAYS,
                          CASE WHEN I.PLAN_COST_START <= P.PERIOD_END_DATE AND I.PLAN_COST_FINISH >= P.PERIOD_START_DATE
                               THEN DATEDIFF(D,CASE WHEN I.PLAN_COST_START > P.PERIOD_START_DATE THEN I.PLAN_COST_START ELSE P.PERIOD_START_DATE END,
                                               CASE WHEN I.PLAN_COST_FINISH < P.PERIOD_END_DATE THEN I.PLAN_COST_FINISH ELSE P.PERIOD_END_DATE END) + 1
                               ELSE 0 END PLAN_COST_PERIOD_DAYS,
                          DATEDIFF(D,I.PLAN_COST_START,I.PLAN_COST_FINISH) + 1 PLAN_COST_TOTAL_DAYS
                   FROM   ppm_dwh.DWH_X_INV_SUM_FACTS I
                          INNER JOIN ppm_dwh.DWH_CMN_PERIOD P ON P.PERIOD_TYPE_KEY = 'FISCAL' 
                                 AND CASE WHEN I.BDGT_COST_START <= I.BDGT_BENEFIT_START
                                           AND I.BDGT_COST_START <= I.PLAN_COST_START
                                           AND I.BDGT_COST_START <= I.PLAN_BENEFIT_START THEN I.BDGT_COST_START
                                          WHEN I.BDGT_BENEFIT_START <= I.BDGT_COST_START
                                           AND I.BDGT_BENEFIT_START <= I.PLAN_COST_START
                                           AND I.BDGT_BENEFIT_START <= I.PLAN_BENEFIT_START THEN I.BDGT_BENEFIT_START
                                          WHEN I.PLAN_COST_START <= I.BDGT_BENEFIT_START
                                           AND I.PLAN_COST_START <= I.BDGT_COST_START
                                           AND I.PLAN_COST_START <= I.PLAN_BENEFIT_START THEN I.PLAN_COST_START
                                          ELSE I.PLAN_BENEFIT_START END <= P.PERIOD_END_DATE
                                 AND CASE WHEN I.BDGT_COST_FINISH <= I.BDGT_BENEFIT_FINISH
                                           AND I.BDGT_COST_FINISH <= I.PLAN_COST_FINISH
                                           AND I.BDGT_COST_FINISH <= I.PLAN_BENEFIT_FINISH THEN I.BDGT_COST_FINISH
                                          WHEN I.BDGT_BENEFIT_FINISH <= I.BDGT_COST_FINISH
                                           AND I.BDGT_BENEFIT_FINISH <= I.PLAN_COST_FINISH
                                           AND I.BDGT_BENEFIT_FINISH <= I.PLAN_BENEFIT_FINISH THEN I.BDGT_BENEFIT_FINISH
                                          WHEN I.PLAN_COST_FINISH <= I.BDGT_BENEFIT_FINISH
                                           AND I.PLAN_COST_FINISH <= I.BDGT_COST_FINISH
                                           AND I.PLAN_COST_FINISH <= I.PLAN_BENEFIT_FINISH THEN I.PLAN_COST_FINISH
                                          ELSE I.PLAN_BENEFIT_FINISH END >= P.PERIOD_START_DATE
                   WHERE  I.PLANS_EXIST = 0) P ON I.INVESTMENT_KEY = P.INVESTMENT_KEY
       LEFT OUTER JOIN (SELECT T.INVESTMENT_KEY,
                               P.PERIOD_KEY,
                               SUM(F.HOME_ACTUAL_COST) ACTUAL_COST,
                               SUM(CASE WHEN T.COST_TYPE_KEY = 'CAPITAL' THEN F.HOME_ACTUAL_COST ELSE 0 END) ACTUAL_CAP_COST,
                               SUM(CASE WHEN T.COST_TYPE_KEY = 'OPERATING' THEN F.HOME_ACTUAL_COST ELSE 0 END) ACTUAL_OPER_COST,
                               SUM(CASE WHEN F.DW_UPDATED_DATE > A.DW_UPDATED_DATE OR T.DW_UPDATED_DATE > A.DW_UPDATED_DATE THEN 1 ELSE 0 END) UNPROCESSED_RECORD_COUNT
                        FROM   PPM_DWH.DWH_FIN_TRANSACTION_FACTS F
                               INNER JOIN PPM_DWH.DWH_CFG_AUDIT A ON UPPER(A.TABLE_NAME) = 'DWH_INV_PERIOD_FACTS'
                               INNER JOIN PPM_DWH.DWH_CMN_PERIOD FP ON F.PERIOD_KEY = FP.PERIOD_KEY 
                               INNER JOIN PPM_DWH.DWH_CMN_PERIOD P ON P.PERIOD_TYPE_KEY = 'FISCAL' 
                                                                  AND FP.PERIOD_START_DATE BETWEEN P.PERIOD_START_DATE AND P.PERIOD_END_DATE
                               INNER JOIN PPM_DWH.DWH_FIN_TRANSACTION T ON F.TRANSACTION_KEY = T.TRANSACTION_KEY
                        GROUP BY T.INVESTMENT_KEY, P.PERIOD_KEY) TF ON P.INVESTMENT_KEY = TF.INVESTMENT_KEY
                                                                   AND P.PERIOD_KEY = TF.PERIOD_KEY
GO
